==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fbayesspam-2.0-2.2.7.tar.gz: bayesspam/bayesspam.sql <==
# phpMyAdmin MySQL-Dump
# version 2.3.0
# http://phpwizard.net/phpMyAdmin/
# http://www.phpmyadmin.net/ (download page)
#
# Host: localhost
# Generation Time: Aug 21, 2002 at 06:23 PM
# Server version: 3.23.51
# PHP Version: 4.2.2
# Database : `spamCorpus`
# --------------------------------------------------------

#
# Table structure for table `Corpus`
#

CREATE TABLE Corpus (
  UserName varchar(175) NOT NULL default '',
  Token varchar(128) NOT NULL default '',
  Score float NOT NULL default '0',
  PRIMARY KEY  (UserName,Token)
) TYPE=MyISAM;
# --------------------------------------------------------

#
# Table structure for table `nonspamOccurences`
#

CREATE TABLE nonspamOccurences (
  UserName varchar(175) NOT NULL default '',
  Token varchar(128) NOT NULL default '',
  Frequency int(10) unsigned NOT NULL default '0',
  LastUpdate timestamp(14) NOT NULL,
  KEY Token (UserName,Token)
) TYPE=MyISAM;
# --------------------------------------------------------

#
# Table structure for table `spamOccurences`
#

CREATE TABLE spamOccurences (
  UserName varchar(175) NOT NULL default '',
  Token varchar(128) NOT NULL default '',
  Frequency int(10) unsigned NOT NULL default '0',
  LastUpdate timestamp(14) NOT NULL,
  KEY Token (UserName,Token)
) TYPE=MyISAM;
# --------------------------------------------------------

#
# Table structure for table `users`
#

CREATE TABLE users (
  UserName varchar(175) NOT NULL default '',
  nonspamCount int(10) unsigned NOT NULL default '0',
  spamCount int(10) unsigned NOT NULL default '0',
  LastRebuild datetime NOT NULL default '0000-00-00 00:00:00',
  LastAdd datetime NOT NULL default '0000-00-00 00:00:00',
  PRIMARY KEY  (UserName)
) TYPE=MyISAM;
# --------------------------------------------------------

#
# Table structure for table `Messages`
#

CREATE TABLE Messages (
  UserName varchar(175) NOT NULL default '',
  MessageID varchar(255) NOT NULL default '',
  Type enum('spam','nonspam') NOT NULL default 'spam',
  Added timestamp(14) NOT NULL,
  PRIMARY KEY  (UserName,MessageID)
) TYPE=MyISAM;
# --------------------------------------------------------

#
# Table structure for table `ScoreCache`
#

CREATE TABLE ScoreCache (
  UserName varchar(175) NOT NULL default '',
  MessageID varchar(255) NOT NULL default '',
  Score float NOT NULL default '0',
  Added timestamp(14) NOT NULL,
  PRIMARY KEY  (UserName,MessageID)
) TYPE=MyISAM;

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fbayesspam-3.1.1-1.2.tar.gz: bayesspam/bayesspam.sql <==
# phpMyAdmin MySQL-Dump
# version 2.3.0
# http://phpwizard.net/phpMyAdmin/
# http://www.phpmyadmin.net/ (download page)
#
# Host: localhost
# Generation Time: Aug 21, 2002 at 06:23 PM
# Server version: 3.23.51
# PHP Version: 4.2.2
# Database : `spamCorpus`
# --------------------------------------------------------

#
# Table structure for table `Corpus`
#

CREATE TABLE Corpus (
  UserName varchar(175) NOT NULL default '',
  Token varchar(128) binary NOT NULL default '',
  Score float NOT NULL default '0',
  PRIMARY KEY  (UserName,Token)
) TYPE=MyISAM;
# --------------------------------------------------------

#
# Table structure for table `nonspamOccurences`
#

CREATE TABLE nonspamOccurences (
  UserName varchar(175) NOT NULL default '',
  Token varchar(128) binary NOT NULL default '',
  Frequency int(10) unsigned NOT NULL default '0',
  LastUpdate timestamp(14) NOT NULL,
  PRIMARY KEY  (UserName,Token)
) TYPE=MyISAM;
# --------------------------------------------------------

#
# Table structure for table `spamOccurences`
#

CREATE TABLE spamOccurences (
  UserName varchar(175) NOT NULL default '',
  Token varchar(128) binary NOT NULL default '',
  Frequency int(10) unsigned NOT NULL default '0',
  LastUpdate timestamp(14) NOT NULL,
  PRIMARY KEY  (UserName,Token)
) TYPE=MyISAM;
# --------------------------------------------------------

#
# Table structure for table `users`
#

CREATE TABLE users (
  UserName varchar(175) NOT NULL default '',
  nonspamCount int(10) unsigned NOT NULL default '0',
  spamCount int(10) unsigned NOT NULL default '0',
  LastRebuild datetime NOT NULL default '0000-00-00 00:00:00',
  LastAdd datetime NOT NULL default '0000-00-00 00:00:00',
  PRIMARY KEY  (UserName)
) TYPE=MyISAM;
# --------------------------------------------------------

#
# Table structure for table `Messages`
#

CREATE TABLE Messages (
  UserName varchar(175) NOT NULL default '',
  MessageID varchar(255) NOT NULL default '',
  Type enum('spam','nonspam') NOT NULL default 'spam',
  Added timestamp(14) NOT NULL,
  PRIMARY KEY  (UserName,MessageID)
) TYPE=MyISAM;
# --------------------------------------------------------

#
# Table structure for table `ScoreCache`
#

CREATE TABLE ScoreCache (
  UserName varchar(175) NOT NULL default '',
  MessageID varchar(255) NOT NULL default '',
  Score float NOT NULL default '0',
  Added timestamp(14) NOT NULL,
  PRIMARY KEY  (UserName,MessageID)
) TYPE=MyISAM;
